@@ -1,8 +1,8 @@
 ClassMDplot  <- function(Data, Cls, ColorSequence = DataVisualizations::DefaultColorSequence,
-                         ClassNames = NULL, PlotLegend = TRUE,
+                         ClassNames = NULL, PlotLegend = TRUE,Ordering = "Columnwise",
                          main = 'MDplot for each Class',
                          xlab = 'Classes', ylab = 'PDE of Data per Class',
-                         MinimalAmoutOfData=40,MinimalAmoutOfUniqueData=12,SampleSize=1e+05) {
+                         MinimalAmoutOfData=40,MinimalAmoutOfUniqueData=12,SampleSize=1e+05,...) {
   # PlotHandle = ClassViolinplot(Data,Cls,ColorSequence,ColorSymbSequence,PlotLegend);
   # BoxPlot the data for all classes, weight the Plot with 1 (= maximum likelihood)
   # INPUT
@@ -67,12 +67,12 @@ ClassMDplot  <- function(Data, Cls, ColorSequence = DataVisualizations::DefaultC
   
   if (is.null(ClassNames)) {
     ClassNames = unique(Cls)
-    ClassNames <- paste("C", ClassNames, sep = "")
+    ClassNames <- paste("Class ", ClassNames, sep = "")
   }else{
     if(!is.character(ClassNames)){
       warning('ClassNames should be a character vector. Ignoring input and setting to default.')
       ClassNames = unique(Cls)
-      ClassNames <- paste("C", ClassNames, sep = "")
+      ClassNames <- paste("Class ", ClassNames, sep = "")
     }
   }
   
@@ -100,82 +100,91 @@ ClassMDplot  <- function(Data, Cls, ColorSequence = DataVisualizations::DefaultC
     # ClassColorsHex[Cls==UniqueClasses[i]]=ColorsUniqueHex[i]
   }
 
-  ClassData = data.frame(cbind(data = Data, class = Cls))
-  ClassData=cbind(ClassData,ClassColors=Colors,ClassNames=ClassNamesVec)#,ClassColorsHex=ClassColorsHex)
-  sorted=order(ClassData$class,decreasing = FALSE,na.last = T)
-  ClassData=ClassData[sorted,]
+  DataPerClassList=vector(mode="list",length = NrOfClasses)
   for(i in 1:NrOfClasses){
-    x=ClassData$data[Cls==UniqueClasses[i]]
-    if(length(unique(x))<MinimalAmoutOfUniqueData){
-      x=JitterUniqueValues(x,NULL)
-      ClassData$data[Cls==UniqueClasses[i]]=x
-    }
+    DataPerClassList[[i]]=Data[Cls==UniqueClasses[i]]
   }
-
-  ClassData$class=factor(ClassData$class)
-  ClassData$ClassColors=factor(ClassData$ClassColors)
-  ClassData$ClassNames=factor(ClassData$ClassNames) 
-  #ClassData$ClassColorsHex=factor(ClassData$ClassColorsHex) 
-
-  Npervar=c()
-  NUniquepervar=c()
-  for(i in 1:length(UniqueClasses)){
-    Npervar[i]=sum(Cls==UniqueClasses[i])
-    NUniquepervar[i]=length(unique(Data[Cls==UniqueClasses[i]]))
-  }
-
-  if(any(Npervar<MinimalAmoutOfData)){
-    ClassData2=ClassData
-    for(i in 1:length(UniqueClasses)){
-      if(Npervar[i]<MinimalAmoutOfData){
-        ClassData2[ClassData2$class==UniqueClasses[i],'data']=NaN
-      }
-    }
-  }else{
-    ClassData2=ClassData
-  }
-
-  Colors=as.vector(ClassData2$ClassColors)
-  names(Colors)=as.vector(ClassData2$class)
-  Colors=Colors[unique(names(Colors))]
-
-  UniqueClassesPlot=ClassData2$class
-  names(UniqueClassesPlot)=as.vector(ClassData2$ClassNames)
-  UniqueClassesPlot=UniqueClassesPlot[unique(names(UniqueClassesPlot))]
-
-  ggobject = ggplot2::ggplot(ClassData2,  aes_string(x = 'class', y = 'data',fill = 'class'),show.legend = PlotLegend) +
-    
-  ggplot2::geom_violin(stat = "PDEdensity",aes_string(x='class', y='data',fill = 'class'),scale='width',show.legend = PlotLegend)
-    
-    
-  # ggobject <- ggplot(ClassData, aes(x = factor(class), y = data)) +
-  #   
-  #   geom_boxplot(aes(fill = factor(class)), notch = FALSE) +
-  #   stat_summary(
-  #     fun.y = "mean",
-  #     geom = "point",
-  #     shape = 23,
-  #     size = 3,
-  #     fill = "white"
-  #   ) +
-
+  DataPerClass=as.matrix(do.call(CombineCols,DataPerClassList))
   
-  if(any(Npervar<MinimalAmoutOfData) | any(NUniquepervar<MinimalAmoutOfData)){
-    DataJitter=ClassData
-    for(i in 1:length(UniqueClasses)){
-      if(Npervar[i]>MinimalAmoutOfData | NUniquepervar[i]>MinimalAmoutOfData){
-        DataJitter[DataJitter$class==UniqueClasses[i],'data']=NaN
-      }
-    }
-    ggobject=ggobject+geom_jitter(size=2,data =DataJitter,aes_string(x = 'class', y = 'data',fill='class'),position=position_jitter(0.15),show.legend = PlotLegend)
-    
-  }
-
+  ggobject=MDplot(Data = DataPerClass,Names = ClassNames,Ordering = Ordering,
+                  QuantityThreshold = MinimalAmoutOfData,
+                  UniqueValuesThreshold = MinimalAmoutOfUniqueData,SampleSize = SampleSize,OnlyPlotOutput = TRUE,...)
+  # ClassData = data.frame(cbind(data = Data, class = Cls))
+  # ClassData=cbind(ClassData,ClassColors=Colors,ClassNames=ClassNamesVec)#,ClassColorsHex=ClassColorsHex)
+  # sorted=order(ClassData$class,decreasing = FALSE,na.last = T)
+  # ClassData=ClassData[sorted,]
+  # for(i in 1:NrOfClasses){
+  #   x=ClassData$data[Cls==UniqueClasses[i]]
+  #   if(length(unique(x))<MinimalAmoutOfUniqueData){
+  #     x=JitterUniqueValues(x,NULL)
+  #     ClassData$data[Cls==UniqueClasses[i]]=x
+  #   }
+  # }
+  # 
+  # ClassData$class=factor(ClassData$class)
+  # ClassData$ClassColors=factor(ClassData$ClassColors)
+  # ClassData$ClassNames=factor(ClassData$ClassNames) 
+  # #ClassData$ClassColorsHex=factor(ClassData$ClassColorsHex) 
+  # 
+  # Npervar=c()
+  # NUniquepervar=c()
+  # for(i in 1:length(UniqueClasses)){
+  #   Npervar[i]=sum(Cls==UniqueClasses[i])
+  #   NUniquepervar[i]=length(unique(Data[Cls==UniqueClasses[i]]))
+  # }
+  # 
+  # if(any(Npervar<MinimalAmoutOfData)){
+  #   ClassData2=ClassData
+  #   for(i in 1:length(UniqueClasses)){
+  #     if(Npervar[i]<MinimalAmoutOfData){
+  #       ClassData2[ClassData2$class==UniqueClasses[i],'data']=NaN
+  #     }
+  #   }
+  # }else{
+  #   ClassData2=ClassData
+  # }
+  # 
+  # Colors=as.vector(ClassData2$ClassColors)
+  # names(Colors)=as.vector(ClassData2$class)
+  # Colors=Colors[unique(names(Colors))]
+  # 
+  # UniqueClassesPlot=ClassData2$class
+  # names(UniqueClassesPlot)=as.vector(ClassData2$ClassNames)
+  # UniqueClassesPlot=UniqueClassesPlot[unique(names(UniqueClassesPlot))]
+  # 
+  # ggobject = ggplot2::ggplot(ClassData2,  aes_string(x = 'class', y = 'data',fill = 'class'),show.legend = PlotLegend) +
+  #   
+  # ggplot2::geom_violin(stat = "PDEdensity",aes_string(x='class', y='data',fill = 'class'),scale='width',show.legend = PlotLegend)
+  #   
+  #   
+  # # ggobject <- ggplot(ClassData, aes(x = factor(class), y = data)) +
+  # #   
+  # #   geom_boxplot(aes(fill = factor(class)), notch = FALSE) +
+  # #   stat_summary(
+  # #     fun.y = "mean",
+  # #     geom = "point",
+  # #     shape = 23,
+  # #     size = 3,
+  # #     fill = "white"
+  # #   ) +
+  # 
+  # 
+  # if(any(Npervar<MinimalAmoutOfData) | any(NUniquepervar<MinimalAmoutOfData)){
+  #   DataJitter=ClassData
+  #   for(i in 1:length(UniqueClasses)){
+  #     if(Npervar[i]>MinimalAmoutOfData | NUniquepervar[i]>MinimalAmoutOfData){
+  #       DataJitter[DataJitter$class==UniqueClasses[i],'data']=NaN
+  #     }
+  #   }
+  #   ggobject=ggobject+geom_jitter(size=2,data =DataJitter,aes_string(x = 'class', y = 'data',fill='class'),position=position_jitter(0.15),show.legend = PlotLegend)
+  #   
+  # }
+  # 
   ggobject=ggobject+ylab(ylab) + xlab(xlab) +
-    scale_x_discrete(limits=UniqueClassesPlot,labels = ClassNames) +
-    scale_fill_manual(limits=UniqueClassesPlot,values = Colors,
-                      name = "Classes") +
-    ggtitle(main)+ theme(axis.text.x = element_text(angle = 45, hjust = 1,size = rel(1.2)))
+  #   scale_x_discrete(limits=UniqueClassesPlot,labels = ClassNames) +
+  #   scale_fill_manual(limits=UniqueClassesPlot,values = Colors,
+  #                     name = "Classes") +
+            ggtitle(main)+ theme(axis.text.x = element_text(angle = 45, hjust = 1,size = rel(1.2)))
 
 
   if (isFALSE(PlotLegend)){
@@ -184,6 +193,6 @@ ClassMDplot  <- function(Data, Cls, ColorSequence = DataVisualizations::DefaultC
   
   
   print(ggobject)
-  return(invisible(list(ClassData = ClassData, ggobject = ggobject)))
+  return(invisible(list(ClassData = DataPerClass, ggobject = ggobject)))
   
 }
\ No newline at end of file
