@@ -11,8 +11,8 @@ MDplot4multiplevectors = function(...,
                                   MDscaling = 'width',
                                   LineSize = 0.01,
                                   LineColor = 'black',
-                                  MinimalAmoutOfData = 40,
-                                  MinimalAmoutOfUniqueData = 12,
+                                  QuantityThreshold = 40,
+                                  UniqueValuesThreshold = 12,
                                   SampleSize = 5e+05,
                                   SizeOfJitteredPoints = 1,
                                   OnlyPlotOutput = TRUE) {
@@ -65,8 +65,8 @@ MDplot4multiplevectors = function(...,
     MDscaling = MDscaling,
     LineSize = LineSize,
     LineColor = LineColor,
-    MinimalAmoutOfData = MinimalAmoutOfData,
-    MinimalAmoutOfUniqueData = MinimalAmoutOfUniqueData,
+    QuantityThreshold = QuantityThreshold,
+    UniqueValuesThreshold = UniqueValuesThreshold,
     SampleSize = SampleSize,
     SizeOfJitteredPoints = SizeOfJitteredPoints,
     OnlyPlotOutput = OnlyPlotOutput
